package main

import "github.com/Mikubill/transfer/cmd"

func main() {
	cmd.Execute()
}
